@@ -11,17 +11,21 @@
 # under the License.
 
 import datetime
+import typing as ty
 import urllib
 import uuid
 
 try:
-    from lxml import etree
+    # explicitly re-export symbol
+    # https://mypy.readthedocs.io/en/stable/command_line.html#cmdoption-mypy-no-implicit-reexport
+    from lxml import etree as etree
 except ImportError:
-    etree = None
+    etree = None  # type: ignore[assignment]
 
 from keystoneauth1 import access
 from keystoneauth1 import exceptions
 from keystoneauth1.extras._saml2.v3 import base
+from keystoneauth1 import session as ks_session
 
 
 class Password(base.BaseSAMLPlugin):
@@ -35,21 +39,44 @@ class Password(base.BaseSAMLPlugin):
     NAMESPACES = {
         's': 'http://www.w3.org/2003/05/soap-envelope',
         'a': 'http://www.w3.org/2005/08/addressing',
-        'u': ('http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
-              'wss-wssecurity-utility-1.0.xsd')
+        'u': (
+            'http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
+            'wss-wssecurity-utility-1.0.xsd'
+        ),
     }
 
     ADFS_TOKEN_NAMESPACES = {
         's': 'http://www.w3.org/2003/05/soap-envelope',
-        't': 'http://docs.oasis-open.org/ws-sx/ws-trust/200512'
+        't': 'http://docs.oasis-open.org/ws-sx/ws-trust/200512',
     }
-    ADFS_ASSERTION_XPATH = ('/s:Envelope/s:Body'
-                            '/t:RequestSecurityTokenResponseCollection'
-                            '/t:RequestSecurityTokenResponse')
+    ADFS_ASSERTION_XPATH = (
+        '/s:Envelope/s:Body'
+        '/t:RequestSecurityTokenResponseCollection'
+        '/t:RequestSecurityTokenResponse'
+    )
 
-    def __init__(self, auth_url, identity_provider, identity_provider_url,
-                 service_provider_endpoint, username, password,
-                 protocol, service_provider_entity_id=None, **kwargs):
+    def __init__(
+        self,
+        auth_url: str,
+        identity_provider: str,
+        identity_provider_url: str,
+        service_provider_endpoint: str,
+        username: str,
+        password: str,
+        protocol: str,
+        service_provider_entity_id: ty.Optional[str] = None,
+        *,
+        trust_id: ty.Optional[str] = None,
+        system_scope: ty.Optional[str] = None,
+        domain_id: ty.Optional[str] = None,
+        domain_name: ty.Optional[str] = None,
+        project_id: ty.Optional[str] = None,
+        project_name: ty.Optional[str] = None,
+        project_domain_id: ty.Optional[str] = None,
+        project_domain_name: ty.Optional[str] = None,
+        reauthenticate: bool = True,
+        include_catalog: bool = True,
+    ):
         """Constructor for ``ADFSPassword``.
 
         :param auth_url: URL of the Identity Service
@@ -78,15 +105,29 @@ class Password(base.BaseSAMLPlugin):
         :type password: string
 
         """
-        super(Password, self).__init__(
-            auth_url=auth_url, identity_provider=identity_provider,
+        super().__init__(
+            auth_url=auth_url,
+            identity_provider=identity_provider,
             identity_provider_url=identity_provider_url,
-            username=username, password=password, protocol=protocol, **kwargs)
+            username=username,
+            password=password,
+            protocol=protocol,
+            trust_id=trust_id,
+            system_scope=system_scope,
+            domain_id=domain_id,
+            domain_name=domain_name,
+            project_id=project_id,
+            project_name=project_name,
+            project_domain_id=project_domain_id,
+            project_domain_name=project_domain_name,
+            reauthenticate=reauthenticate,
+            include_catalog=include_catalog,
+        )
 
         self.service_provider_endpoint = service_provider_endpoint
         self.service_provider_entity_id = service_provider_entity_id
 
-    def _cookies(self, session):
+    def _cookies(self, session: ks_session.Session) -> bool:
         """Check if cookie jar is not empty.
 
         keystoneauth1.session.Session object doesn't have a cookies attribute.
@@ -94,19 +135,15 @@ class Password(base.BaseSAMLPlugin):
         requests.Session object. If that fails too, there is something wrong
         and let Python raise the AttributeError.
 
-        :param session
+        :param session: A session object to extract cookies from
         :returns: True if cookie jar is nonempty, False otherwise
         :raises AttributeError: in case cookies are not find anywhere
-
         """
-        try:
-            return bool(session.cookies)
-        except AttributeError:
-            pass
-
         return bool(session.session.cookies)
 
-    def _token_dates(self, fmt='%Y-%m-%dT%H:%M:%S.%fZ'):
+    def _token_dates(
+        self, fmt: str = '%Y-%m-%dT%H:%M:%S.%fZ'
+    ) -> tuple[str, str]:
         """Calculate created and expires datetime objects.
 
         The method is going to be used for building ADFS Request Security
@@ -122,148 +159,207 @@ class Password(base.BaseSAMLPlugin):
         :type fmt: string
 
         """
-        date_created = datetime.datetime.utcnow()
+        date_created = datetime.datetime.now(datetime.timezone.utc).replace(
+            tzinfo=None
+        )
         date_expires = date_created + datetime.timedelta(
-            seconds=self.DEFAULT_ADFS_TOKEN_EXPIRATION)
-        return [_time.strftime(fmt) for _time in (date_created, date_expires)]
+            seconds=self.DEFAULT_ADFS_TOKEN_EXPIRATION
+        )
+        return date_created.strftime(fmt), date_expires.strftime(fmt)
 
-    def _prepare_adfs_request(self):
+    def _prepare_adfs_request(self) -> None:
         """Build the ADFS Request Security Token SOAP message.
 
         Some values like username or password are inserted in the request.
 
         """
         WSS_SECURITY_NAMESPACE = {
-            'o': ('http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
-                  'wss-wssecurity-secext-1.0.xsd')
+            'o': (
+                'http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
+                'wss-wssecurity-secext-1.0.xsd'
+            )
         }
 
         TRUST_NAMESPACE = {
             'trust': 'http://docs.oasis-open.org/ws-sx/ws-trust/200512'
         }
 
-        WSP_NAMESPACE = {
-            'wsp': 'http://schemas.xmlsoap.org/ws/2004/09/policy'
-        }
+        WSP_NAMESPACE = {'wsp': 'http://schemas.xmlsoap.org/ws/2004/09/policy'}
 
-        WSA_NAMESPACE = {
-            'wsa': 'http://www.w3.org/2005/08/addressing'
-        }
+        WSA_NAMESPACE = {'wsa': 'http://www.w3.org/2005/08/addressing'}
 
         root = etree.Element(
             '{http://www.w3.org/2003/05/soap-envelope}Envelope',
-            nsmap=self.NAMESPACES)
+            nsmap=self.NAMESPACES,
+        )
 
         header = etree.SubElement(
-            root, '{http://www.w3.org/2003/05/soap-envelope}Header')
+            root, '{http://www.w3.org/2003/05/soap-envelope}Header'
+        )
         action = etree.SubElement(
-            header, "{http://www.w3.org/2005/08/addressing}Action")
+            header, "{http://www.w3.org/2005/08/addressing}Action"
+        )
         action.set(
-            "{http://www.w3.org/2003/05/soap-envelope}mustUnderstand", "1")
-        action.text = ('http://docs.oasis-open.org/ws-sx/ws-trust/200512'
-                       '/RST/Issue')
+            "{http://www.w3.org/2003/05/soap-envelope}mustUnderstand", "1"
+        )
+        action.text = (
+            'http://docs.oasis-open.org/ws-sx/ws-trust/200512/RST/Issue'
+        )
 
         messageID = etree.SubElement(
-            header, '{http://www.w3.org/2005/08/addressing}MessageID')
+            header, '{http://www.w3.org/2005/08/addressing}MessageID'
+        )
         messageID.text = 'urn:uuid:' + uuid.uuid4().hex
         replyID = etree.SubElement(
-            header, '{http://www.w3.org/2005/08/addressing}ReplyTo')
+            header, '{http://www.w3.org/2005/08/addressing}ReplyTo'
+        )
         address = etree.SubElement(
-            replyID, '{http://www.w3.org/2005/08/addressing}Address')
+            replyID, '{http://www.w3.org/2005/08/addressing}Address'
+        )
         address.text = 'http://www.w3.org/2005/08/addressing/anonymous'
 
         to = etree.SubElement(
-            header, '{http://www.w3.org/2005/08/addressing}To')
+            header, '{http://www.w3.org/2005/08/addressing}To'
+        )
         to.set("{http://www.w3.org/2003/05/soap-envelope}mustUnderstand", "1")
 
         security = etree.SubElement(
-            header, '{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
+            header,
+            '{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
             'wss-wssecurity-secext-1.0.xsd}Security',
-            nsmap=WSS_SECURITY_NAMESPACE)
+            nsmap=WSS_SECURITY_NAMESPACE,
+        )
 
         security.set(
-            "{http://www.w3.org/2003/05/soap-envelope}mustUnderstand", "1")
+            "{http://www.w3.org/2003/05/soap-envelope}mustUnderstand", "1"
+        )
 
         timestamp = etree.SubElement(
-            security, ('{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
-                       'wss-wssecurity-utility-1.0.xsd}Timestamp'))
+            security,
+            (
+                '{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
+                'wss-wssecurity-utility-1.0.xsd}Timestamp'
+            ),
+        )
         timestamp.set(
-            ('{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
-             'wss-wssecurity-utility-1.0.xsd}Id'), '_0')
+            (
+                '{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
+                'wss-wssecurity-utility-1.0.xsd}Id'
+            ),
+            '_0',
+        )
 
         created = etree.SubElement(
-            timestamp, ('{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
-                        'wss-wssecurity-utility-1.0.xsd}Created'))
+            timestamp,
+            (
+                '{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
+                'wss-wssecurity-utility-1.0.xsd}Created'
+            ),
+        )
 
         expires = etree.SubElement(
-            timestamp, ('{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
-                        'wss-wssecurity-utility-1.0.xsd}Expires'))
+            timestamp,
+            (
+                '{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
+                'wss-wssecurity-utility-1.0.xsd}Expires'
+            ),
+        )
 
         created.text, expires.text = self._token_dates()
 
         usernametoken = etree.SubElement(
-            security, '{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
-                      'wss-wssecurity-secext-1.0.xsd}UsernameToken')
+            security,
+            '{http://docs.oasis-open.org/wss/2004/01/oasis-200401-'
+            'wss-wssecurity-secext-1.0.xsd}UsernameToken',
+        )
         usernametoken.set(
-            ('{http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-'
-             'wssecurity-utility-1.0.xsd}u'), "uuid-%s-1" % uuid.uuid4().hex)
+            (
+                '{http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-'
+                'wssecurity-utility-1.0.xsd}u'
+            ),
+            f"uuid-{uuid.uuid4().hex}-1",
+        )
 
         username = etree.SubElement(
-            usernametoken, ('{http://docs.oasis-open.org/wss/2004/01/oasis-'
-                            '200401-wss-wssecurity-secext-1.0.xsd}Username'))
+            usernametoken,
+            (
+                '{http://docs.oasis-open.org/wss/2004/01/oasis-'
+                '200401-wss-wssecurity-secext-1.0.xsd}Username'
+            ),
+        )
         password = etree.SubElement(
-            usernametoken, ('{http://docs.oasis-open.org/wss/2004/01/oasis-'
-                            '200401-wss-wssecurity-secext-1.0.xsd}Password'),
-            Type=('http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-'
-                  'username-token-profile-1.0#PasswordText'))
+            usernametoken,
+            (
+                '{http://docs.oasis-open.org/wss/2004/01/oasis-'
+                '200401-wss-wssecurity-secext-1.0.xsd}Password'
+            ),
+            Type=(
+                'http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-'
+                'username-token-profile-1.0#PasswordText'
+            ),
+        )
 
         body = etree.SubElement(
-            root, "{http://www.w3.org/2003/05/soap-envelope}Body")
+            root, "{http://www.w3.org/2003/05/soap-envelope}Body"
+        )
 
         request_security_token = etree.SubElement(
-            body, ('{http://docs.oasis-open.org/ws-sx/ws-trust/200512}'
-                   'RequestSecurityToken'), nsmap=TRUST_NAMESPACE)
+            body,
+            (
+                '{http://docs.oasis-open.org/ws-sx/ws-trust/200512}'
+                'RequestSecurityToken'
+            ),
+            nsmap=TRUST_NAMESPACE,
+        )
 
         applies_to = etree.SubElement(
             request_security_token,
             '{http://schemas.xmlsoap.org/ws/2004/09/policy}AppliesTo',
-            nsmap=WSP_NAMESPACE)
+            nsmap=WSP_NAMESPACE,
+        )
 
         endpoint_reference = etree.SubElement(
             applies_to,
             '{http://www.w3.org/2005/08/addressing}EndpointReference',
-            nsmap=WSA_NAMESPACE)
+            nsmap=WSA_NAMESPACE,
+        )
 
         wsa_address = etree.SubElement(
-            endpoint_reference,
-            '{http://www.w3.org/2005/08/addressing}Address')
+            endpoint_reference, '{http://www.w3.org/2005/08/addressing}Address'
+        )
 
         keytype = etree.SubElement(
             request_security_token,
-            '{http://docs.oasis-open.org/ws-sx/ws-trust/200512}KeyType')
-        keytype.text = ('http://docs.oasis-open.org/ws-sx/'
-                        'ws-trust/200512/Bearer')
+            '{http://docs.oasis-open.org/ws-sx/ws-trust/200512}KeyType',
+        )
+        keytype.text = (
+            'http://docs.oasis-open.org/ws-sx/ws-trust/200512/Bearer'
+        )
 
         request_type = etree.SubElement(
             request_security_token,
-            '{http://docs.oasis-open.org/ws-sx/ws-trust/200512}RequestType')
-        request_type.text = ('http://docs.oasis-open.org/ws-sx/'
-                             'ws-trust/200512/Issue')
+            '{http://docs.oasis-open.org/ws-sx/ws-trust/200512}RequestType',
+        )
+        request_type.text = (
+            'http://docs.oasis-open.org/ws-sx/ws-trust/200512/Issue'
+        )
         token_type = etree.SubElement(
             request_security_token,
-            '{http://docs.oasis-open.org/ws-sx/ws-trust/200512}TokenType')
+            '{http://docs.oasis-open.org/ws-sx/ws-trust/200512}TokenType',
+        )
         token_type.text = 'urn:oasis:names:tc:SAML:1.0:assertion'
 
         # After constructing the request, let's plug in some values
         username.text = self.username
         password.text = self.password
         to.text = self.identity_provider_url
-        wsa_address.text = (self.service_provider_entity_id or
-                            self.service_provider_endpoint)
+        wsa_address.text = (
+            self.service_provider_entity_id or self.service_provider_endpoint
+        )
 
         self.prepared_request = root
 
-    def _get_adfs_security_token(self, session):
+    def _get_adfs_security_token(self, session: ks_session.Session) -> None:
         """Send ADFS Security token to the ADFS server.
 
         Store the result in the instance attribute and raise an exception in
@@ -288,14 +384,26 @@ class Password(base.BaseSAMLPlugin):
                  recognized.
 
         """
-        def _get_failure(e):
-            xpath = '/s:Envelope/s:Body/s:Fault/s:Code/s:Subcode/s:Value'
-            content = e.response.content
+
+        request_security_token = self.xml_to_str(self.prepared_request)
+        try:
+            response = session.post(
+                url=self.identity_provider_url,
+                headers=self.HEADER_SOAP,
+                data=request_security_token,
+                authenticated=False,
+            )
+        except exceptions.InternalServerError as e:
+            if e.response is None:
+                raise
+
             try:
-                obj = self.str_to_xml(content).xpath(
-                    xpath, namespaces=self.NAMESPACES)
+                obj = self.str_to_xml(e.response.content).xpath(
+                    '/s:Envelope/s:Body/s:Fault/s:Code/s:Subcode/s:Value',
+                    namespaces=self.NAMESPACES,
+                )
                 obj = self._first(obj)
-                return obj.text
+                reason = obj.text
             # NOTE(marek-denis): etree.Element.xpath() doesn't raise an
             # exception, it just returns an empty list. In that case, _first()
             # will raise IndexError and we should treat it as an indication XML
@@ -304,20 +412,14 @@ class Password(base.BaseSAMLPlugin):
             # re-raise exceptions.InternalServerError.
             except (IndexError, exceptions.AuthorizationFailure):
                 raise e
-
-        request_security_token = self.xml_to_str(self.prepared_request)
-        try:
-            response = session.post(
-                url=self.identity_provider_url, headers=self.HEADER_SOAP,
-                data=request_security_token, authenticated=False)
-        except exceptions.InternalServerError as e:
-            reason = _get_failure(e)
             raise exceptions.AuthorizationFailure(reason)
-        msg = ('Error parsing XML returned from '
-               'the ADFS Identity Provider, reason: %s')
+        msg = (
+            'Error parsing XML returned from '
+            'the ADFS Identity Provider, reason: %s'
+        )
         self.adfs_token = self.str_to_xml(response.content, msg)
 
-    def _prepare_sp_request(self):
+    def _prepare_sp_request(self) -> None:
         """Prepare ADFS Security Token to be sent to the Service Provider.
 
         The method works as follows:
@@ -328,7 +430,8 @@ class Password(base.BaseSAMLPlugin):
 
         """
         assertion = self.adfs_token.xpath(
-            self.ADFS_ASSERTION_XPATH, namespaces=self.ADFS_TOKEN_NAMESPACES)
+            self.ADFS_ASSERTION_XPATH, namespaces=self.ADFS_TOKEN_NAMESPACES
+        )
         assertion = self._first(assertion)
         assertion = self.xml_to_str(assertion)
         # TODO(marek-denis): Ideally no string replacement should occur.
@@ -337,12 +440,15 @@ class Password(base.BaseSAMLPlugin):
         # from scratch and reuse values from the adfs security token.
         assertion = assertion.replace(
             b'http://docs.oasis-open.org/ws-sx/ws-trust/200512',
-            b'http://schemas.xmlsoap.org/ws/2005/02/trust')
+            b'http://schemas.xmlsoap.org/ws/2005/02/trust',
+        )
 
         encoded_assertion = urllib.parse.quote(assertion)
         self.encoded_assertion = 'wa=wsignin1.0&wresult=' + encoded_assertion
 
-    def _send_assertion_to_service_provider(self, session):
+    def _send_assertion_to_service_provider(
+        self, session: ks_session.Session
+    ) -> None:
         """Send prepared assertion to a service provider.
 
         As the assertion doesn't contain a protected resource, the value from
@@ -357,10 +463,14 @@ class Password(base.BaseSAMLPlugin):
 
         """
         session.post(
-            url=self.service_provider_endpoint, data=self.encoded_assertion,
-            headers=self.HEADER_X_FORM, redirect=False, authenticated=False)
+            url=self.service_provider_endpoint,
+            data=self.encoded_assertion,
+            headers=self.HEADER_X_FORM,
+            redirect=False,
+            authenticated=False,
+        )
 
-    def _access_service_provider(self, session):
+    def _access_service_provider(self, session: ks_session.Session) -> None:
         """Access protected endpoint and fetch unscoped token.
 
         After federated authentication workflow a protected endpoint should be
@@ -381,11 +491,15 @@ class Password(base.BaseSAMLPlugin):
         if self._cookies(session) is False:
             raise exceptions.AuthorizationFailure(
                 "Session object doesn't contain a cookie, therefore you are "
-                "not allowed to enter the Identity Provider's protected area.")
-        self.authenticated_response = session.get(self.federated_token_url,
-                                                  authenticated=False)
+                "not allowed to enter the Identity Provider's protected area."
+            )
+        self.authenticated_response = session.get(
+            self.federated_token_url, authenticated=False
+        )
 
-    def get_unscoped_auth_ref(self, session, *kwargs):
+    def get_unscoped_auth_ref(
+        self, session: ks_session.Session
+    ) -> access.AccessInfoV3:
         """Retrieve unscoped token after authentcation with ADFS server.
 
         This is a multistep process:
@@ -427,4 +541,6 @@ class Password(base.BaseSAMLPlugin):
         self._send_assertion_to_service_provider(session)
         self._access_service_provider(session)
 
-        return access.create(resp=self.authenticated_response)
+        access_info = access.create(resp=self.authenticated_response)
+        assert isinstance(access_info, access.AccessInfoV3)  # nosec B101
+        return access_info
