@@ -25,19 +25,15 @@ from keystoneauth1 import session as ks_session
 
 
 class _Saml2TokenAuthMethod(v3.AuthMethod):
-    _method_parameters = []
+    def __init__(self) -> None: ...
 
-    # TODO(stephenfin): Deprecate and remove unused kwargs
     def get_auth_data(
         self,
         session: ks_session.Session,
         auth: v3.Auth,
-        headers: ty.Dict[str, str],
-        request_kwargs: ty.Dict[str, object],
-        **kwargs: ty.Any,
-    ) -> ty.Union[
-        ty.Tuple[None, None], ty.Tuple[str, ty.Mapping[str, object]]
-    ]:
+        headers: dict[str, str],
+        request_kwargs: dict[str, object],
+    ) -> ty.Union[tuple[None, None], tuple[str, ty.Mapping[str, object]]]:
         raise exceptions.HttpNotImplemented(
             'This method should never be called'
         )
@@ -71,7 +67,7 @@ class BaseSAMLPlugin(v3.FederationBaseAuth):
         project_domain_name: ty.Optional[str] = None,
         reauthenticate: bool = True,
         include_catalog: bool = True,
-    ):
+    ) -> None:
         """Class constructor accepting following parameters.
 
         :param auth_url: URL of the Identity Service
@@ -122,7 +118,7 @@ class BaseSAMLPlugin(v3.FederationBaseAuth):
         self.password = password
 
     @staticmethod
-    def _first(_list: ty.List[_T]) -> _T:
+    def _first(_list: list[_T]) -> _T:
         if len(_list) != 1:
             raise IndexError('Only single element list is acceptable')
         return _list[0]
