@@ -28,32 +28,35 @@ class PasswordMethod(base.AuthMethod):
     :param string user_domain_name: User's domain name for authentication.
     """
 
-    user_id: str
-    username: str
-    user_domain_id: str
-    user_domain_name: str
     password: str
+    user_id: ty.Optional[str] = None
+    username: ty.Optional[str] = None
+    user_domain_id: ty.Optional[str] = None
+    user_domain_name: ty.Optional[str] = None
 
-    _method_parameters = [
-        'user_id',
-        'username',
-        'user_domain_id',
-        'user_domain_name',
-        'password',
-    ]
+    def __init__(
+        self,
+        *,
+        password: str,
+        user_id: ty.Optional[str] = None,
+        username: ty.Optional[str] = None,
+        user_domain_id: ty.Optional[str] = None,
+        user_domain_name: ty.Optional[str] = None,
+    ) -> None:
+        self.password = password
+        self.user_id = user_id
+        self.username = username
+        self.user_domain_id = user_domain_id
+        self.user_domain_name = user_domain_name
 
-    # TODO(stephenfin): Deprecate and remove unused kwargs
     def get_auth_data(
         self,
         session: ks_session.Session,
         auth: base.Auth,
-        headers: ty.Dict[str, str],
-        request_kwargs: ty.Dict[str, object],
-        **kwargs: ty.Any,
-    ) -> ty.Union[
-        ty.Tuple[None, None], ty.Tuple[str, ty.Mapping[str, object]]
-    ]:
-        user: ty.Dict[str, ty.Any] = {'password': self.password}
+        headers: dict[str, str],
+        request_kwargs: dict[str, object],
+    ) -> ty.Union[tuple[None, None], tuple[str, ty.Mapping[str, object]]]:
+        user: dict[str, ty.Any] = {'password': self.password}
 
         if self.user_id:
             user['id'] = self.user_id
@@ -67,19 +70,23 @@ class PasswordMethod(base.AuthMethod):
 
         return 'password', {'user': user}
 
-    def get_cache_id_elements(self) -> ty.Dict[str, ty.Optional[str]]:
+    def get_cache_id_elements(self) -> dict[str, ty.Optional[str]]:
         return {
-            f'password_{p}': getattr(self, p) for p in self._method_parameters
+            'password_password': self.password,
+            'password_user_id': self.user_id,
+            'password_username': self.username,
+            'password_user_domain_id': self.user_domain_id,
+            'password_user_domain_name': self.user_domain_name,
         }
 
 
-class Password(base.AuthConstructor):
+class Password(base.Auth):
     """A plugin for authenticating with a username and password.
 
     :param string auth_url: Identity service endpoint for authentication.
     :param string password: Password for authentication.
-    :param string username: Username for authentication.
     :param string user_id: User ID for authentication.
+    :param string username: Username for authentication.
     :param string user_domain_id: User's domain ID for authentication.
     :param string user_domain_name: User's domain name for authentication.
     :param string trust_id: Trust ID for trust scoping.
@@ -95,3 +102,47 @@ class Password(base.AuthConstructor):
     """
 
     _auth_method_class = PasswordMethod
+
+    def __init__(
+        self,
+        auth_url: str,
+        password: str,
+        user_id: ty.Optional[str] = None,
+        username: ty.Optional[str] = None,
+        user_domain_id: ty.Optional[str] = None,
+        user_domain_name: ty.Optional[str] = None,
+        *,
+        unscoped: bool = False,
+        trust_id: ty.Optional[str] = None,
+        system_scope: ty.Optional[str] = None,
+        domain_id: ty.Optional[str] = None,
+        domain_name: ty.Optional[str] = None,
+        project_id: ty.Optional[str] = None,
+        project_name: ty.Optional[str] = None,
+        project_domain_id: ty.Optional[str] = None,
+        project_domain_name: ty.Optional[str] = None,
+        reauthenticate: bool = True,
+        include_catalog: bool = True,
+    ) -> None:
+        method = self._auth_method_class(
+            password=password,
+            user_id=user_id,
+            username=username,
+            user_domain_id=user_domain_id,
+            user_domain_name=user_domain_name,
+        )
+        super().__init__(
+            auth_url,
+            [method],
+            unscoped=unscoped,
+            trust_id=trust_id,
+            system_scope=system_scope,
+            domain_id=domain_id,
+            domain_name=domain_name,
+            project_id=project_id,
+            project_name=project_name,
+            project_domain_id=project_domain_id,
+            project_domain_name=project_domain_name,
+            reauthenticate=reauthenticate,
+            include_catalog=include_catalog,
+        )
