@@ -27,27 +27,24 @@ class TokenMethod(base.AuthMethod):
 
     token: str
 
-    _method_parameters = ['token']
+    def __init__(self, *, token: str) -> None:
+        self.token = token
 
-    # TODO(stephenfin): Deprecate and remove unused kwargs
     def get_auth_data(
         self,
         session: ks_session.Session,
         auth: base.Auth,
-        headers: ty.Dict[str, str],
-        request_kwargs: ty.Dict[str, object],
-        **kwargs: ty.Any,
-    ) -> ty.Union[
-        ty.Tuple[None, None], ty.Tuple[str, ty.Mapping[str, object]]
-    ]:
+        headers: dict[str, str],
+        request_kwargs: dict[str, object],
+    ) -> ty.Union[tuple[None, None], tuple[str, ty.Mapping[str, object]]]:
         headers['X-Auth-Token'] = self.token
         return 'token', {'id': self.token}
 
-    def get_cache_id_elements(self) -> ty.Dict[str, ty.Optional[str]]:
+    def get_cache_id_elements(self) -> dict[str, ty.Optional[str]]:
         return {'token_token': self.token}
 
 
-class Token(base.AuthConstructor):
+class Token(base.Auth):
     """A plugin for authenticating with an existing Token.
 
     :param string auth_url: Identity service endpoint for authentication.
@@ -81,11 +78,11 @@ class Token(base.AuthConstructor):
         project_domain_name: ty.Optional[str] = None,
         reauthenticate: bool = True,
         include_catalog: bool = True,
-        **kwargs: ty.Any,
-    ):
+    ) -> None:
+        method = self._auth_method_class(token=token)
         super().__init__(
             auth_url,
-            token=token,
+            [method],
             unscoped=unscoped,
             trust_id=trust_id,
             system_scope=system_scope,
