@@ -33,7 +33,7 @@ class NoAuth(loading.BaseLoader[noauth.NoAuth]):
     def plugin_class(self) -> ty.Type[noauth.NoAuth]:
         return noauth.NoAuth
 
-    def get_options(self) -> ty.List[opts.Opt]:
+    def get_options(self) -> list[opts.Opt]:
         options = super().get_options()
 
         options.extend(
