@@ -37,16 +37,16 @@ class Adapter(base._BaseLoader[adapter.Adapter]):
     def plugin_class(self) -> ty.Type[adapter.Adapter]:
         return adapter.Adapter
 
-    def get_options(self) -> ty.List['opts.Opt']:
+    def get_options(self) -> list['opts.Opt']:
         return []
 
     @staticmethod
     def get_conf_options(
         include_deprecated: bool = True,
         deprecated_opts: ty.Optional[
-            ty.Dict[str, ty.List['cfg.DeprecatedOpt']]
+            dict[str, list['cfg.DeprecatedOpt']]
         ] = None,
-    ) -> ty.List['cfg.Opt']:
+    ) -> list['cfg.Opt']:
         """Get oslo_config options that are needed for a :py:class:`.Adapter`.
 
         These may be useful without being registered for config file generation
@@ -207,8 +207,7 @@ class Adapter(base._BaseLoader[adapter.Adapter]):
             opts += [
                 cfg.StrOpt(
                     'interface',
-                    help='The default interface for endpoint URL '
-                    'discovery.',
+                    help='The default interface for endpoint URL discovery.',
                     deprecated_for_removal=True,
                     deprecated_reason='Using valid-interfaces is'
                     ' preferrable because it is'
@@ -224,9 +223,9 @@ class Adapter(base._BaseLoader[adapter.Adapter]):
         group: str,
         include_deprecated: bool = True,
         deprecated_opts: ty.Optional[
-            ty.Dict[str, ty.List['cfg.DeprecatedOpt']]
+            dict[str, list['cfg.DeprecatedOpt']]
         ] = None,
-    ) -> ty.List['cfg.Opt']:
+    ) -> list['cfg.Opt']:
         """Register the oslo_config options that are needed for an Adapter.
 
         The options that are set are:
@@ -305,7 +304,7 @@ class Adapter(base._BaseLoader[adapter.Adapter]):
 
 
 def process_conf_options(
-    confgrp: 'cfg.OptGroup', kwargs: ty.Dict[str, ty.Any]
+    confgrp: 'cfg.OptGroup', kwargs: dict[str, ty.Any]
 ) -> None:
     """Set Adapter constructor kwargs based on conf options.
 
@@ -318,16 +317,15 @@ def process_conf_options(
     """
     if confgrp.valid_interfaces and getattr(confgrp, 'interface', None):
         raise TypeError(
-            "interface and valid_interfaces are mutually"
-            " exclusive. Please use valid_interfaces."
+            "interface and valid_interfaces are mutually "
+            "exclusive. Please use valid_interfaces."
         )
     if confgrp.valid_interfaces:
         for iface in confgrp.valid_interfaces:
             if iface not in ('public', 'internal', 'admin'):
-                # TODO(efried): s/valies/values/ - are we allowed to fix this?
                 raise TypeError(
                     f"'{iface}' is not a valid value for"
-                    " valid_interfaces. Valid valies are"
+                    " valid_interfaces. Valid values are"
                     " public, internal or admin"
                 )
         kwargs.setdefault('interface', confgrp.valid_interfaces)
@@ -371,10 +369,8 @@ def register_conf_options(
     conf: 'cfg.ConfigOpts',
     group: str,
     include_deprecated: bool = True,
-    deprecated_opts: ty.Optional[
-        ty.Dict[str, ty.List['cfg.DeprecatedOpt']]
-    ] = None,
-) -> ty.List['cfg.Opt']:
+    deprecated_opts: ty.Optional[dict[str, list['cfg.DeprecatedOpt']]] = None,
+) -> list['cfg.Opt']:
     return Adapter().register_conf_options(
         conf,
         group,
@@ -391,8 +387,6 @@ def load_from_conf_options(
 
 def get_conf_options(
     include_deprecated: bool = True,
-    deprecated_opts: ty.Optional[
-        ty.Dict[str, ty.List['cfg.DeprecatedOpt']]
-    ] = None,
-) -> ty.List['cfg.Opt']:
+    deprecated_opts: ty.Optional[dict[str, list['cfg.DeprecatedOpt']]] = None,
+) -> list['cfg.Opt']:
     return Adapter.get_conf_options(include_deprecated, deprecated_opts)
