@@ -70,7 +70,7 @@ class Opt:
         help: ty.Optional[str] = None,
         secret: bool = False,
         dest: ty.Optional[str] = None,
-        deprecated: ty.Optional[ty.List['Opt']] = None,
+        deprecated: ty.Optional[list['Opt']] = None,
         default: ty.Any = None,
         metavar: ty.Optional[str] = None,
         required: bool = False,
@@ -137,16 +137,21 @@ class Opt:
         return itertools.chain([self], self.deprecated)
 
     @property
-    def argparse_args(self) -> ty.List[str]:
+    def argparse_args(self) -> list[str]:
         return [f'--os-{o.name}' for o in self._all_opts]
 
+    @property
+    def argparse_envvars(self) -> ty.List[str]:
+        return [
+            'OS_{}'.format(o.name.replace('-', '_').upper())
+            for o in self._all_opts
+        ]
+
     @property
     def argparse_default(self) -> ty.Any:
         # select the first ENV that is not false-y or return None
-        for o in self._all_opts:
-            v = os.environ.get(
-                'OS_{}'.format(o.name.replace('-', '_').upper())
-            )
+        for envvar in self.argparse_envvars:
+            v = os.environ.get(envvar)
             if v:
                 return v
 
